<?php

namespace Litecms\Affiliatetable\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Affiliatetable\Models\Affiliatetable;

class AffiliatetablePolicy
{

    /**
     * Determine if the given user can view the affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function view(UserPolicy $user, Affiliatetable $affiliatetable)
    {
        if ($user->canDo('affiliatetable.affiliatetable.view') && $user->isAdmin()) {
            return true;
        }

        return $affiliatetable->user_id == user_id() && $affiliatetable->user_type == user_type();
    }

    /**
     * Determine if the given user can create a affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('affiliatetable.affiliatetable.create');
    }

    /**
     * Determine if the given user can update the given affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function update(UserPolicy $user, Affiliatetable $affiliatetable)
    {
        if ($user->canDo('affiliatetable.affiliatetable.edit') && $user->isAdmin()) {
            return true;
        }

        return $affiliatetable->user_id == user_id() && $affiliatetable->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Affiliatetable $affiliatetable)
    {
        return $affiliatetable->user_id == user_id() && $affiliatetable->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Affiliatetable $affiliatetable)
    {
        if ($user->canDo('affiliatetable.affiliatetable.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given affiliatetable.
     *
     * @param UserPolicy $user
     * @param Affiliatetable $affiliatetable
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Affiliatetable $affiliatetable)
    {
        if ($user->canDo('affiliatetable.affiliatetable.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
